@@ -1,7 +1,11 @@
 require 'arel/crud'
+require 'arel/factory_methods'
 
 require 'arel/expressions'
 require 'arel/predications'
+require 'arel/math'
+require 'arel/alias_predication'
+require 'arel/order_predications'
 require 'arel/table'
 require 'arel/attributes'
 require 'arel/compatibility/wheres'
@@ -21,6 +25,7 @@ require 'arel/update_manager'
 require 'arel/delete_manager'
 require 'arel/nodes'
 
+
 #### these are deprecated
 require 'arel/deprecated'
 require 'arel/sql/engine'
@@ -28,9 +33,15 @@ require 'arel/sql_literal'
 ####
 
 module Arel
-  VERSION = '2.0.4'
+  VERSION = '2.2.1'
 
   def self.sql raw_sql
     Arel::Nodes::SqlLiteral.new raw_sql
   end
+
+  def self.star
+    sql '*'
+  end
+  ## Convenience Alias
+  Node = Arel::Nodes::Node
 end
