@@ -3,6 +3,16 @@ module Arel
     ###
     # Abstract base class for all AST nodes
     class Node
+      include Arel::FactoryMethods
+      include Enumerable
+
+      ###
+      # Factory method to create a Nodes::Not node that has the recipient of
+      # the caller as a child.
+      def not
+        Nodes::Not.new self
+      end
+
       ###
       # Factory method to create a Nodes::Grouping node that has an Nodes::Or
       # node as a child.
@@ -13,7 +23,7 @@ module Arel
       ###
       # Factory method to create an Nodes::And node.
       def and right
-        Nodes::And.new self, right
+        Nodes::And.new [self, right]
       end
 
       # FIXME: this method should go away.  I don't like people calling
@@ -22,8 +32,14 @@ module Arel
       #
       # Maybe we should just use `Table.engine`?  :'(
       def to_sql engine = Table.engine
-        viz = Visitors.for engine
-        viz.accept self
+        engine.connection.visitor.accept self
+      end
+
+      # Iterate through AST, nodes will be yielded depth-first
+      def each &block
+        return enum_for(:each) unless block_given?
+
+        Visitors::DepthFirst.new(block).accept self
       end
     end
   end
