@@ -3,6 +3,8 @@ module Arel
     class SqlLiteral < String
       include Arel::Expressions
       include Arel::Predications
+      include Arel::AliasPredication
+      include Arel::OrderPredications
     end
   end
 end
