@@ -1,14 +1,16 @@
 module Arel
   module Nodes
-    class UpdateStatement
+    class UpdateStatement < Arel::Nodes::Node
       attr_accessor :relation, :wheres, :values, :orders, :limit
+      attr_accessor :key
 
       def initialize
         @relation = nil
         @wheres   = []
         @values   = []
-        @orders = []
-        @limit  = nil
+        @orders   = []
+        @limit    = nil
+        @key      = nil
       end
 
       def initialize_copy other
