@@ -3,7 +3,7 @@ module Arel
     class SQLite < Arel::Visitors::ToSql
       private
       def visit_Arel_Nodes_SelectStatement o
-        o.limit = -1 if o.offset && !o.limit
+        o.limit = Arel::Nodes::Limit.new(-1) if o.offset && !o.limit
         super
       end
     end
